Learn R Programming

miRada (version 0.1.11-13)

CXCR: Clinical relevance of CXCL12/CXCR4 and Hedgehog

Description

Determine the clinical relevance of CXCL12/CXCR4 and Hedgehog interaction in pancreatic cancer.

Usage

data(CXCR)

Arguments

encoding

UTF-8

format

Three small data set: cxcr4, cxcr7, and shh.

References

Sanjeev K. Srivastava , Arun Bhardwaj , Seema Singh , Sumit Arora , Bin Wang , William E. Grizzle and Ajay P. Singh (2011) "MicroRNA-150 directly targets MUC4 and suppresses growth and malignant behavior of pancreatic cancer cells", Carcinogenesis, doi:10.1093/carcin/bgr223. (PMID 21983127).

Arora S., Bhardwaj A., Srivastava S.K., Singh S., McClellan S., Wang B., Singh A.P. (2011) "Honokiol arrests cell cycle, induces apoptosis and potentiates the cytotoxic effects of gemcitabine in human pancreatic cancer cells", PLoS One, 6 (6), e21573.

Examples

Run this code
data(CXCR)
  shh

Run the code above in your browser using DataLab